@@ -3,14 +3,14 @@ if __name__ == "__main__":
     from gitee import GiteeRepo
     from urlparse import URL
     from crypto import CryptoHandler
-    from exceptions import ColumnDataDoesNotFit, ColumnNotFoundError, \
-                           DataWasNotGiven, DataWasNotGivenError
+    from exceptions import (ColumnDataDoesNotFit, ColumnNotFoundError, 
+                           DataWasNotGiven, DataWasNotGivenError)
 else:
     from .gitee import GiteeRepo
     from .urlparse import URL
     from .crypto import CryptoHandler
-    from .exceptions import ColumnDataDoesNotFit, ColumnNotFoundError, \
-                            DataWasNotGiven, DataWasNotGivenError
+    from .exceptions import (ColumnDataDoesNotFit, ColumnNotFoundError,
+                            DataWasNotGiven, DataWasNotGivenError)
 
 import json, warnings
 
@@ -136,6 +136,9 @@ class table_objects:
     def filter(self, *args, **kwargs):
         """ Usage: filter(**namespace) """
         if len(kwargs) == 1 and self.obj.index in kwargs:
+            if not kwargs[self.obj.index] in self.obj.repo.list_file(path=self.obj.name):
+                print(ColumnNotFoundError(URL(self.obj.name) / kwargs[self.obj.index]))
+                return []
             return [SqleeColumn(
                     path = URL(self.obj.name) / kwargs[self.obj.index],
                     repo = self.obj.repo,
